==> fcitx_4.2.4.1.orig.tar.xz: fcitx-4.2.4.1/src/im/keyboard/keyboardconfig.c <==
/***************************************************************************
 *   Copyright (C) 2012~2012 by CSSlayer                                   *
 *   wengxt@gmail.com                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.              *
 ***************************************************************************/
#include "keyboard.h"

CONFIG_BINDING_BEGIN(FcitxKeyboardConfig);
CONFIG_BINDING_REGISTER("Keyboard", "CommitWithExtraSpace", bCommitWithExtraSpace);
CONFIG_BINDING_REGISTER("Keyboard", "HotkeyToggleWordHint", hkToggleWordHint);
CONFIG_BINDING_REGISTER("Keyboard", "EnableWordHint", bEnableWordHint);
CONFIG_BINDING_REGISTER("Keyboard", "MinimumHintLength", minimumHintLength);
CONFIG_BINDING_REGISTER("Keyboard", "UsePresage", bUsePresage);
CONFIG_BINDING_REGISTER("Keyboard", "UseEnterToCommit", bUseEnterToCommit);
CONFIG_BINDING_REGISTER("Keyboard", "HotkeyAddToUserDict", hkAddToUserDict);
CONFIG_BINDING_REGISTER("Keyboard", "PreferredEnchantProvider", provider);
CONFIG_BINDING_END();

==> fcitx_4.2.9.1.orig.tar.xz: fcitx-4.2.9.1/src/im/keyboard/keyboardconfig.c <==
/***************************************************************************
 *   Copyright (C) 2012~2012 by CSSlayer                                   *
 *   wengxt@gmail.com                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.              *
 ***************************************************************************/
#include "keyboard.h"

CONFIG_BINDING_BEGIN(FcitxKeyboardConfig);
CONFIG_BINDING_REGISTER("Keyboard", "CommitWithExtraSpace",
                        bCommitWithExtraSpace);
CONFIG_BINDING_REGISTER("Keyboard", "HotkeyToggleWordHint", hkToggleWordHint);
CONFIG_BINDING_REGISTER("Keyboard", "MinimumHintLength", minimumHintLength);
CONFIG_BINDING_REGISTER("Keyboard", "MaximumHintLength", maximumHintLength);
CONFIG_BINDING_REGISTER("Keyboard", "UseEnterToCommit", bUseEnterToCommit);
CONFIG_BINDING_REGISTER("Keyboard", "HotkeyAddToUserDict", hkAddToUserDict);
CONFIG_BINDING_REGISTER("Keyboard", "ChooseModifier", chooseModifier);
CONFIG_BINDING_END();
